@@ -7,7 +7,6 @@
 */
 
 #include "lunarphase.h"
-#include <config-kholidays.h>
 
 #include <QCoreApplication>
 #include <QDateTime>
@@ -32,6 +31,14 @@ QString LunarPhase::phaseName(LunarPhase::Phase phase)
         return (QCoreApplication::translate("LunarPhase", "Last Quarter Moon"));
     case None:
         return QString();
+    case WaxingCrescent:
+        return (QCoreApplication::translate("LunarPhase", "Waxing Crescent"));
+    case WaxingGibbous:
+        return (QCoreApplication::translate("LunarPhase", "Waxing Gibbous"));
+    case WaningGibbous:
+        return (QCoreApplication::translate("LunarPhase", "Waning Gibbous"));
+    case WaningCrescent:
+        return (QCoreApplication::translate("LunarPhase", "Waning Crescent"));
     }
     return QString();
 }
@@ -48,14 +55,23 @@ LunarPhase::Phase LunarPhase::phaseAtDate(const QDate &date)
     const QDateTime todayEnd(date.addDays(1), midnight, Qt::UTC);
     const double endAngle = phaseAngle(todayEnd.toMSecsSinceEpoch());
 
-    if (startAngle > endAngle)
+    if (startAngle > endAngle) {
         retPhase = NewMoon;
-    else if (startAngle < 90.0 && endAngle > 90.0)
+    } else if (startAngle < 90.0 && endAngle > 90.0) {
         retPhase = FirstQuarter;
-    else if (startAngle < 180.0 && endAngle > 180.0)
+    } else if (startAngle < 180.0 && endAngle > 180.0) {
         retPhase = FullMoon;
-    else if (startAngle < 270.0 && endAngle > 270.0)
+    } else if (startAngle < 270.0 && endAngle > 270.0) {
         retPhase = LastQuarter;
+    } else if (endAngle < 90.0) {
+        retPhase = WaxingCrescent;
+    } else if (endAngle < 180.0) {
+        retPhase = WaxingGibbous;
+    } else if (endAngle < 270.0) {
+        retPhase = WaningGibbous;
+    } else if (endAngle < 360.0) {
+        retPhase = WaningCrescent;
+    }
 
     return retPhase;
 }
